.. _faq:

===========================
Frequently Asked Questions
===========================

.. contents:: :local:

How can I ask a question not covered here?
------------------------------------------

See `Contributing <contributing.rst>`_ for how to report bugs and ask questions.

Opening a github issue is preferred, because then other people can find the question and answer.
